@@ -36,6 +36,51 @@
 #include "plugin-script-config.h"
 
 
+struct t_weechat_script_constant weechat_script_constants[] = {
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_RC_OK),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_RC_OK_EAT),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_RC_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_READ_OK),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_READ_MEMORY_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_READ_FILE_NOT_FOUND),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_WRITE_OK),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_WRITE_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_WRITE_MEMORY_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_SET_OK_CHANGED),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_SET_OK_SAME_VALUE),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_SET_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_SET_OPTION_NOT_FOUND),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_UNSET_OK_NO_RESET),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_UNSET_OK_RESET),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_UNSET_OK_REMOVED),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_CONFIG_OPTION_UNSET_ERROR),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_LIST_POS_SORT),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_LIST_POS_BEGINNING),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_LIST_POS_END),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOTLIST_LOW),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOTLIST_MESSAGE),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOTLIST_PRIVATE),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOTLIST_HIGHLIGHT),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_PROCESS_RUNNING),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_PROCESS_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_OK),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_ADDRESS_NOT_FOUND),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_IP_ADDRESS_NOT_FOUND),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_CONNECTION_REFUSED),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_PROXY_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_LOCAL_HOSTNAME_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_GNUTLS_INIT_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_GNUTLS_HANDSHAKE_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_MEMORY_ERROR),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_TIMEOUT),
+    WEECHAT_SCRIPT_CONST_INT(WEECHAT_HOOK_CONNECT_SOCKET_ERROR),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOOK_SIGNAL_STRING),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOOK_SIGNAL_INT),
+    WEECHAT_SCRIPT_CONST_STR(WEECHAT_HOOK_SIGNAL_POINTER),
+    { NULL, 0, NULL },
+};
+
+
 /*
  * Displays name and version of interpreter used.
  */
@@ -225,8 +270,7 @@ plugin_script_init (struct t_weechat_plugin *weechat_plugin,
             N_("Without argument, this command lists all loaded scripts.")),
         completion,
         plugin_data->callback_command, NULL, NULL);
-    if (completion)
-        free (completion);
+    free (completion);
 
     /* add completion, hdata and infolist */
     snprintf (string, sizeof (string), "%s_script", weechat_plugin->name);
@@ -278,8 +322,7 @@ plugin_script_init (struct t_weechat_plugin *weechat_plugin,
     auto_load_scripts = (info_auto_load_scripts
                          && (strcmp (info_auto_load_scripts, "1") == 0)) ?
         1 : 0;
-    if (info_auto_load_scripts)
-        free (info_auto_load_scripts);
+    free (info_auto_load_scripts);
 
     /* autoload scripts */
     if (auto_load_scripts)
@@ -1022,22 +1065,14 @@ plugin_script_remove_configs (struct t_weechat_plugin *weechat_plugin,
 void
 plugin_script_free (struct t_plugin_script *script)
 {
-    if (script->filename)
-        free (script->filename);
-    if (script->name)
-        free (script->name);
-    if (script->author)
-        free (script->author);
-    if (script->version)
-        free (script->version);
-    if (script->license)
-        free (script->license);
-    if (script->description)
-        free (script->description);
-    if (script->shutdown_func)
-        free (script->shutdown_func);
-    if (script->charset)
-        free (script->charset);
+    free (script->filename);
+    free (script->name);
+    free (script->author);
+    free (script->version);
+    free (script->license);
+    free (script->description);
+    free (script->shutdown_func);
+    free (script->charset);
 
     free (script);
 }
@@ -1324,8 +1359,7 @@ plugin_script_action_install (struct t_weechat_plugin *weechat_plugin,
                                         free (symlink_path);
                                     }
                                     free (autoload_path);
-                                    if (dir_separator)
-                                        free (dir_separator);
+                                    free (dir_separator);
                                 }
                             }
 
@@ -1352,8 +1386,7 @@ plugin_script_action_install (struct t_weechat_plugin *weechat_plugin,
                         free (new_path);
                     }
                     free (base_name);
-                    if (weechat_data_dir)
-                        free (weechat_data_dir);
+                    free (weechat_data_dir);
 
                     /* send signal */
                     snprintf (str_signal, sizeof (str_signal),
@@ -1524,8 +1557,7 @@ plugin_script_action_autoload (struct t_weechat_plugin *weechat_plugin,
                                 (void) rc;
                                 free (symlink_path);
                             }
-                            if (dir_separator)
-                                free (dir_separator);
+                            free (dir_separator);
                         }
                         else
                         {
@@ -1534,8 +1566,7 @@ plugin_script_action_autoload (struct t_weechat_plugin *weechat_plugin,
                         free (autoload_path);
                     }
                     free (base_name);
-                    if (weechat_data_dir)
-                        free (weechat_data_dir);
+                    free (weechat_data_dir);
                 }
                 free (name);
             }
@@ -1824,19 +1855,19 @@ plugin_script_print_log (struct t_weechat_plugin *weechat_plugin,
          ptr_script = ptr_script->next_script)
     {
         weechat_log_printf ("");
-        weechat_log_printf ("[script %s (addr:0x%lx)]",      ptr_script->name, ptr_script);
-        weechat_log_printf ("  filename. . . . . . : '%s'",  ptr_script->filename);
-        weechat_log_printf ("  interpreter . . . . : 0x%lx", ptr_script->interpreter);
-        weechat_log_printf ("  name. . . . . . . . : '%s'",  ptr_script->name);
-        weechat_log_printf ("  author. . . . . . . : '%s'",  ptr_script->author);
-        weechat_log_printf ("  version . . . . . . : '%s'",  ptr_script->version);
-        weechat_log_printf ("  license . . . . . . : '%s'",  ptr_script->license);
-        weechat_log_printf ("  description . . . . : '%s'",  ptr_script->description);
-        weechat_log_printf ("  shutdown_func . . . : '%s'",  ptr_script->shutdown_func);
-        weechat_log_printf ("  charset . . . . . . : '%s'",  ptr_script->charset);
-        weechat_log_printf ("  unloading . . . . . : %d",    ptr_script->unloading);
-        weechat_log_printf ("  prev_script . . . . : 0x%lx", ptr_script->prev_script);
-        weechat_log_printf ("  next_script . . . . : 0x%lx", ptr_script->next_script);
+        weechat_log_printf ("[script %s (addr:%p)]", ptr_script->name, ptr_script);
+        weechat_log_printf ("  filename. . . . . . : '%s'", ptr_script->filename);
+        weechat_log_printf ("  interpreter . . . . : %p", ptr_script->interpreter);
+        weechat_log_printf ("  name. . . . . . . . : '%s'", ptr_script->name);
+        weechat_log_printf ("  author. . . . . . . : '%s'", ptr_script->author);
+        weechat_log_printf ("  version . . . . . . : '%s'", ptr_script->version);
+        weechat_log_printf ("  license . . . . . . : '%s'", ptr_script->license);
+        weechat_log_printf ("  description . . . . : '%s'", ptr_script->description);
+        weechat_log_printf ("  shutdown_func . . . : '%s'", ptr_script->shutdown_func);
+        weechat_log_printf ("  charset . . . . . . : '%s'", ptr_script->charset);
+        weechat_log_printf ("  unloading . . . . . : %d", ptr_script->unloading);
+        weechat_log_printf ("  prev_script . . . . : %p", ptr_script->prev_script);
+        weechat_log_printf ("  next_script . . . . : %p", ptr_script->next_script);
     }
 
     weechat_log_printf ("");
